<?php
 defined('VSIGN') or die("Sorry, you are not allowed to directly access this page.<br /> Please press the back button in your browser.");
?>


<div id="system_working" style="display:none;"><img src="img/loading.gif"></div>

<div id="system_message" style="text-align: center;">
	<span>Message</span>
</div>

<div id="div_dialog"></div>
<div id="help_dialog"></div>

<div class="footer" style="display:block;"><a href="http://lokon.vs.co.id/" title="VSign Digital Signage">VSign Digital Signage 2013</a></div>

</div> <!-- Ends the content div -->
</div> <!-- Ends contentwrap div -->
</div> <!-- Ends the container div -->

</body>
</html>