<?php
defined('VSIGN') or die("Sorry, you are not allowed to directly access this page.<br /> Please press the back button in your browser.");

class licenseDAO 
{
	private $db;
	private $user;
	private $has_permissions = true;
	
    function __construct(database $db, user $user) 
	{
		$this->db 	=& $db;
		$this->user =& $user;
    	
    }
    
    function on_page_load() 
	{
		return "";
	}
	
	function echo_page_heading() 
	{
		echo __("License Management");
		return true;
	}
	
	function displayPage() 
	{
		$db =& $this->db;
		
		include("template/pages/license_view.php");
	}
	
	function license_info() 
	{
		$output = <<<END
		<h1>License Information</h1>
		VSign Digital Signage - http://lokon.vs.co.id
		2012
END;
		echo nl2br($output);
	}
}
?>