<?php
defined('VSIGN') or die("Sorry, you are not allowed to directly access this page.<br /> Please press the back button in your browser.");

class errorDAO 
{
	private $db;
	private $user;

	function __construct(database $db, user $user) 
	{
		$this->db 	=& $db;
		$this->user =& $user;
	}
	
	function on_page_load() 
	{
    	return '';
	}
	
	function echo_page_heading() 
	{
		echo __("Application Error");
		return true;
	} 
	
	function displayPage() 
	{
		$db 	=& $this->db;
		$user 	=& $this->user;
		$error	= Kit::GetParam('ErrorMessage', _SESSION, _HTMLSTRING, __('Unknown Error'));
		
		echo __('There has been an application error.');
		echo $error;
		
		exit;
	}
}

?>