body {
	font-size:76.1%;
	font-family:Verdana, Arial, Helvetica, sans-serif;
	background: url(../img/headerback.png) repeat-x;
}

img {
	border:0px;
	
}

.install_box {


	text-align:center;
	margin:auto;
	clear:both;
	width: 500px !important;
	width: 500px;
}

.install_header {
	background: #fe4406;
	width: 500px;
	height: 10px;
}

.install_header_left{
	float:left;
	width: 10px;
	height: 10px;
	background:url(../img/login/login_topleft.png) no-repeat;
	
}

.install_header_right{
	float:right;
	width: 10px;
	height: 10px;
	background:url(../img/login/login_topright.png) no-repeat;
	
}

h1 {
	color: #ffffff;
	font: Arial;
}

p1 {
	color: #003580;
	font: Arial;
}

.install_body {
	background: url(../img/login/login_body.png) repeat-x #ffffff;
	padding: 25px 0 15px 10px;
}
.install_foot{
	background: url(../img/login/login_foot.png) repeat-x;
	height: 19px;
	width: 500px;
}

.install_foot_left{
	float:left;
	width: 11px;
	height: 19px;
	background:url(../img/login/login_bottomleft.png) no-repeat;
	
}

.install_foot_right{
	float:right;
	width: 11px;
	height: 19px;
	background:url(../img/login/login_bottomright.png) no-repeat;
	
}

.install_foot_image{
	float:center;
}

.install_box form {
	
}

.install_table {
	text-align: right;
	margin-right: 55px;
	margin-left: 10px;
}

input.username{
	clear:both;
	height:25px;
	width:100px;
}

input.password{
	clear:both;
	height:25px;
	margin-left:7px;
	width:100px;
}

.button {
	height:40px;
	width: 60px;
	clear:both;
}

.highlight {
	color:red;

}

.checks {
	text-align: left;
	margin-left: 15px;
}

.check_explain {
	margin-left: 18px;
}

.info {
	text-align: left;
	margin-left: 15px;
	margin-right: 15px;
}

#content {
	width:100%;
	margin: 0 auto;
	text-align: left;
}