<?php
defined('VSIGN') or die("Sorry, you are not allowed to directly access this page.<br /> Please press the back button in your browser.");

?>
<div id="form_container">
	<div id="form_header">
		<div id="form_header_left">
		</div>
		<div id="form_header_right">
		</div>
	</div>
	
	<div id="form_body">
		
		<table id="CalendarTable" width="100%" cellpadding=0 cellspacing=0>
			<tr>
				<td id="Nav">
					<div id="NavCalendar">
						
					</div>
					<div id="Displays">
						<?php echo $this->DisplayFilter(); ?>
					</div>
				</td>
				<td valign="top" style="vertical-align: top;">
					<div id="Calendar">
			
					</div>
				</td>
			</tr>
		</table>
	</div>
	<div id="form_footer">
		<div id="form_footer_left">
		</div>
		<div id="form_footer_right">
		</div>
	</div>
</div>	