<?php
defined('VSIGN') or die("Sorry, you are not allowed to directly access this page.<br /> Please press the back button in your browser.");

class Setting extends Data
{
	public function Edit($setting, $value)
	{
		$db =& $this->db;
		
		$SQL = sprintf("UPDATE setting SET value = '%s' WHERE setting = '%s' ", $db->escape_string($value), $db->escape_string($setting));

		if(!$db->query($SQL)) 
		{
			trigger_error($db->error());
			$this->SetError(25000, __('Update of settings failed'));
			
			return false;
		}
		
		return true;
	}
}
?>