<?php
defined('VSIGN') or die("Sorry, you are not allowed to directly access this page.<br /> Please press the back button in your browser.");
 
class dashboardDAO 
{
	private $db;
	private $user;

	function __construct(database $db, user $user) 
	{
		$this->db 	=& $db;
		$this->user =& $user;
	}
	
	function on_page_load() 
	{
		return '';
	}
	
	function echo_page_heading() 
	{
		$user 	=& $this->user;
		
		$userid = Kit::GetParam('userid', _SESSION, _INT);
		
		$uid = $user->getNameFromID($userid);
		
		echo $uid.'\'s ' . __('Dashboard');
		return true;
	}

	function displayPage() 
	{
		$db 	=& $this->db;
		$user 	=& $this->user;

		include_once("template/pages/dashboard.php");
	}
}
?>