<?php
class ServiceOAuth
{
    private $server;

    public function __construct()
    {
        $this->server = new OAuthServer();
    }

    public function request_token()
    {
        $this->server->requestToken();
    }

    public function access_token()
    {
        $this->server->accessToken();
    }
}
?>
