TRUNCATE TABLE help;

INSERT INTO `help` (`HelpID`, `Topic`, `Category`, `Link`) VALUES
(1, 'Layout', 'General', 'http://lokon.vs.co.id'),
(2, 'Content', 'General', 'http://lokon.vs.co.id'),
(4, 'Schedule', 'General', 'http://lokon.vs.co.id'),
(5, 'Group', 'General', 'http://lokon.vs.co.id'),
(6, 'Admin', 'General', 'http://lokon.vs.co.id'),
(7, 'Report', 'General', 'http://lokon.vs.co.id'),
(8, 'Dashboard', 'General', 'http://lokon.vs.co.id'),
(9, 'User', 'General', 'http://lokon.vs.co.id'),
(10, 'Display', 'General', 'http://lokon.vs.co.id'),
(11, 'Displaygroup', 'General', 'http://lokon.vs.co.id'),
(12, 'Layout', 'Add', 'http://lokon.vs.co.id'),
(13, 'Layout', 'Background', 'http://lokon.vs.co.id'),
(14, 'Content', 'Assign', 'http://lokon.vs.co.id'),
(15, 'Layout', 'RegionOptions', 'http://lokon.vs.co.id'),
(16, 'Content', 'AddtoLibrary', 'http://lokon.vs.co.id'),
(17, 'Display', 'Edit', 'http://lokon.vs.co.id'),
(18, 'Display', 'Delete', 'http://lokon.vs.co.id'),
(19, 'Displays', 'Groups', 'http://lokon.vs.co.id'),
(20, 'Groups', 'General', 'http://lokon.vs.co.id'),
(21, 'User', 'Add', 'http://lokon.vs.co.id'),
(22, 'User', 'Delete', 'http://lokon.vs.co.id'),
(23, 'Content', 'Config', 'http://lokon.vs.co.id'),
(24, 'LayoutMedia', 'Permissions', 'http://lokon.vs.co.id'),
(25, 'Region', 'Permissions', 'http://lokon.vs.co.id'),
(26, 'Library', 'Assign', 'http://lokon.vs.co.id'),
(27, 'Media', 'Delete', 'http://lokon.vs.co.id'),
(28, 'DisplayGroup', 'Add', 'http://lokon.vs.co.id'),
(29, 'DisplayGroup', 'Edit', 'http://lokon.vs.co.id'),
(30, 'DisplayGroup', 'Delete', 'http://lokon.vs.co.id'),
(31, 'DisplayGroup', 'Members', 'http://lokon.vs.co.id'),
(32, 'DisplayGroup', 'GroupSecurity', 'http://lokon.vs.co.id');

INSERT INTO `setting` (`settingid`, `setting`, `value`, `type`, `helptext`, `options`, `cat`, `userChange`) VALUES (NULL, 'MAX_LICENSED_DISPLAYS', '0', 'text', 'The maximum number of licensed clients for this server installation. 0 = unlimited', NULL, 'general', '0');

ALTER TABLE  `setting` CHANGE  `setting`  `setting` VARCHAR( 50 ) NOT NULL;
INSERT INTO `setting` (`settingid`, `setting`, `value`, `type`, `helptext`, `options`, `cat`, `userChange`) VALUES (NULL, 'LIBRARY_MEDIA_UPDATEINALL_CHECKB', 'Unchecked', 'dropdown', 'Default the checkbox for updating media on all layouts when editing in the library', 'Checked|Unchecked', 'default', '1');

ALTER TABLE  `display` ADD  `MacAddress` VARCHAR( 254 ) NULL COMMENT  'Mac Address of the Client',
ADD  `LastChanged` INT NULL COMMENT  'Last time this Mac Address changed';

ALTER TABLE  `display` ADD  `NumberOfMacAddressChanges` INT NOT NULL;

UPDATE `version` SET `app_ver` = '1.3.2', `XmdsVersion` = 3;
UPDATE `setting` SET `value` = 0 WHERE `setting` = 'PHONE_HOME_DATE';
UPDATE `version` SET `DBVersion` = '44';