<?php

defined('VSIGN') or die("Sorry, you are not allowed to directly access this page.<br /> Please press the back button in your browser."); 
?>
<div id="form_container">
	<div id="form_header">
		<div id="form_header_left">
		</div>
		<div id="form_header_right">
		</div>
	</div>
	
	<div id="form_body">
		<div class='buttons'>
			<a id="background_button" class="VsignFormButton" href="<?php echo $this->EditBackgroundHref(); ?>" title="Background"><div class="button_text">Background</div></a> 
			<a id="edit_button" class="VsignFormButton" href="<?php echo $this->EditPropertiesHref(); ?>" title="Layout Properties"><div class="button_text">Properties</div></a> 		
			<a id="schedulenow_button" class="VsignFormButton" href="<?php echo $this->ScheduleNowHref(); ?>" title="Schedule Now"><div class="button_text">Schedule Now</div></a>
		</div>
		<div class="leftbuttons">
			<div class="buttons">
                <a id="jumpListButton" class="VsignFormButton" href="index.php?p=layout&q=LayoutJumpList" title="View Next Layout"><div class="button_text">Next Layout</div></a>
				<a id='pres_button' href='index.php?p=layout' alt='Cancel Edit'><div class="button_text">Layout List</div></a>
			</div>	
			
		</div>
			
		<div class="slidetable">
			<div class="title">
				<h4><center><br /><br />Layout Design - <?php echo $this->layout ?></center><br /></h4>
			</div>
			<div class="formbody">
				<center> 
					<?php $this->RenderDesigner(); ?>
				</center>
			</div>
		</div>
	</div>
	
	<div id="form_footer">
		<div id="form_footer_left">
		</div>
		<div id="form_footer_right">
		</div>
	</div>
</div>	
<div id="tooltip_hover" style="position:absolute; top: 0px; left:0px; display:none"></div>
