body {
	font-size:76.1%;
	font-family:Verdana, Arial, Helvetica, sans-serif;
}

.message_box {
	background: #E0E9F6;
	border: 1px solid #003399;
	margin-top: 6em;
	padding-right: 5px;
	text-align:center;
	margin: 10px auto;
	clear:both;
	width: 500px !important;
	width: 500px;
}

.message_header {
	margin-right: -5px; 
	padding-right: 40px;
}

.message_header h1 {
	margin: 0;
	border: 0; 
	padding: 30px 0 15px 40px;
	height: auto !important; 
	height: 1%; /* IE Holly Hack */ 
}

.message_body {
	text-align:left;
	margin-right: 25px; 
	padding: 25px 0 15px 10px;
}

.message_body li{
	list-style-type: circle;
}

.highlight {
	color:red;
	font-size:1.2em;
	display:inline;
	float:none;
	border:0;
	background:none;
}

#content {
	width:100%;
	margin: 0 auto;

}