
function ManageMembersCallBack()
{
	$("#layoutsIn, #layoutsOut").sortable({
		connectWith: '.connectedSortable',
		dropOnEmpty: true
	}).disableSelection();

        $(".li-sortable", "#div_dialog").dblclick(switchLists);
}

function MembersSubmit() {
	// Serialise the form and then submit it via Ajax.
	var href = $("#layoutsIn").attr('href') + "&ajax=true";
	
	// Get the two lists		
	serializedData = $("#layoutsIn").sortable('serialize');
	
	$.ajax({
		type: "post",
		url: href,
		cache: false,
		dataType: "json",
		data: serializedData,
		success: VsignSubmitResponse
	});
	
	return;
}