body {
	font-size:76.1%;
	font-family:Verdana, Arial, Helvetica, sans-serif;
	background: url(../../img/headerback.png) repeat-x;
	margin: 0px;
	
}

img {
	border:0px;
	
}

.lgbx {
	border: 2px solid rgba(153, 153, 153, 0.75);
	border-radius: 2px 2px 2px 2px;
	z-index: 3;
	font-size: 13px !important;
	font-family: "Helvetica Neue",Helvetica,Arial,sans-serif;
	background-color: rgb(255, 255, 255);
	position: relative;
	margin: 0px;
	padding: 0px;
	line-height: 1.22em;
	text-align: left;
	color: rgb(51, 51, 51);
	font: 13px arial,helvetica,clean,sans-serif;
	width: 250px;
}

#container {
	width: 100%;
}

.login_box {
	padding: 20px;
	margin: 0px;
	line-height: 1.22em;
	font-size: 13px !important;
	font-family: "Helvetica Neue",Helvetica,Arial,sans-serif;
	text-align: left;
	color: rgb(51, 51, 51);
	font: 13px arial,helvetica,clean,sans-serif;
}

#fslogin {
	position: relative;
	padding-top: 0px;
	clear: both;
	border: 0px none;
	padding: 10px 0px;
	margin: 0px;
	line-height: 1.22em;
	font-size: 13px !important;
	font-family: "Helvetica Neue",Helvetica,Arial,sans-serif;
	color: rgb(51, 51, 51);
}

#login_headtop {
	background-color: rgb(200, 255, 255);
	background: url("../../img/login/login_head.png");
	font-size: 50px !important;
	font-family: "Helvetica Neue",Helvetica,Arial,sans-serif;
	text-align: center;
	top: 0px;
	height: 118px;
	left: 0px;
	width: 100%;
	z-index: 3;
	line-height: 0.8em;
}

#footer_wrapper {
	background-color: rgb(255, 255, 255);
	bottom: 0px;
	height: 27px;
	left: 0px;
	width: 100%;
	position: fixed;
	line-height: 0.8em;
	z-index: 3;
}

#login_footer {
	background-color: rgb(255, 255, 255);
	background: url("../../img/login/login_bot.png");
	text-align: right;
	margin-right: 20pt;
	bottom: 0px;
	height: 27px;
	left: 0px;
	width: 100%;
	line-height: 0.8em;
	z-index: 3;
}

.login_header {
	background: #fe4406;
	width: 250px;
	height: 10px;
}

.login_header_left{
	float:left;
	width: 10px;
	height: 10px;
	background:url(../../img/login/login_topleft.png) no-repeat;
	
}

.login_header_right{
	float:right;
	width: 10px;
	height: 10px;
	background:url(../../img/login/login_topright.png) no-repeat;
	
}

h1 {
	color: #ffffff;
	font: Arial;
}

p1 {
	color: #003580;
	font: Arial;
}

.login_body {
	background: url(../../img/login/login_body.png) repeat-x #ffffff;
	padding: 25px 0 15px 10px;
}
.login_foot{
	background: url(../../img/login/login_foot.png) repeat-x;
	height: 19px;
	width: 250px;
}

.login_foot_left{
	float:left;
	width: 11px;
	height: 19px;
	background:url(../../img/login/login_bottomleft.png) no-repeat;
	
}

.login_foot_right{
	float:right;
	width: 11px;
	height: 19px;
	background:url(../../img/login/login_bottomright.png) no-repeat;
	
}
.login_box form {
	
}

.login_table {
	padding: 0px;
	margin: 0px;
	line-height: 1.22em;
	font-size: 13px !important;
	font-family: "Helvetica Neue",Helvetica,Arial,sans-serif;
	text-align: left;
	color: rgb(51, 51, 51);
	font: 13px arial,helvetica,clean,sans-serif;
}

input.username{
	border: 1px solid rgb(186, 186, 186);
	margin-bottom: 15px;
	font-size: 107% !important;
	padding: 5px;
	height: 23px;
	width: 208px;
	border-radius: 3px 3px 3px 3px;
	line-height: 1.5;
	font: 99% arial,helvetica,clean,sans-serif;
	text-align: left;
	color: rgb(51, 51, 51);
}

input.password{
	border: 1px solid rgb(186, 186, 186);
	margin-bottom: 15px;
	font-size: 107% !important;
	padding: 5px;
	height: 23px;
	width: 208px;
	border-radius: 3px 3px 3px 3px;
	line-height: 1.5;
	font: 99% arial,helvetica,clean,sans-serif;
	text-align: left;
	color: rgb(51, 51, 51);
}

.loginbuton {
	width:208px;
	border-radius: 2px 2px 2px 2px;
	background-color: rgb(110, 50, 157);
	background-image: -moz-linear-gradient(center center , rgb(110, 50, 157) 0%, rgb(110, 50, 157) 100%);
	border: 1px solid rgb(82, 38, 117);
	padding-bottom: 5px;
}

.logbutton {
	font: 13px arial,helvetica,clean,sans-serif;
	font-family: arial;
	background-color: rgb(110, 50, 157);
	color: rgb(255, 255, 255);
	height: 35px;
	width: 100%;
	font-weight: bold;
	cursor: pointer;
	text-align: center;
	border: 0px none;
}

.button {
	height:40px;
	width: 60px;
	clear:both;
}

.highlight {
	color:red;

}

#content {
	width:100%;
	margin: 0 auto;
	text-align: center;

	
}