/* Tables and Forms */
th.header {
	background:#E0E9F6  no-repeat scroll 0% 50%;
	cursor:pointer;
}
th.headerSortDown {
	background:#E0E9F6  no-repeat scroll 0% 50%;
}
th.headerSortUp {
	background:#E0E9F6  no-repeat scroll 0% 50%;
}

#paging {
	float:right;
	clear:both;
}

.first {
	padding-top: 5px;
	cursor:pointer;
}

.prev {
	padding-top: 5px;
	cursor:pointer;
}

.next{
	padding-top: 5px;
	cursor:pointer;
}

.last{
	padding-top: 5px;
	cursor:pointer;
}

.form_container {
	padding: 10px;
	width:80%;
	margin-left:10%;
}

.filter_form_container {
	margin-top: 0px;
	margin-left: 10px;
	
	width: 98%;
}

#schedule_form_container{
	width:100%;
	float:left;
}

#scanner_table{
	clear:both;
}

.scanresults_container {
	width:98%;
	clear:both;
	margin-left: 10px;
}

.scanresults {
	margin-top:10px;
	margin-left:10px;
	clear:right;
}

.scanresults table {
	clear:both;
}

.scanresults input {
	width: 100px;
}

.scanresults input.readonly {
	background:#FFFFFF;
	border:0;
	text-align:right;
}

.scanresults input.text_left {
	background:#FFFFFF;
	border:0;
	text-align:left;
}

.scanresults input.name_field {
	width: 300px;
}

form.scanresults table, form.scanresults td, form.scanresults th, #stack_media table, #stack_media td, #stack_media th {
	border:1px solid #000000;
    background:#FFFFFF;
	border-collapse:collapse;
	margin:10px 0px 10px 0px;
}

.dialog_table table, .dialog_table td, .dialog_table th {
	border:1px solid #DCE4F5;
    background:#FFFFFF;
	border-collapse:collapse;
	margin:10px 0px 10px 0px;
}

form.scanresults th, #stack_media th, .dialog_table th {
	background:#E0E9F6;
}

td.centered {
	text-align:center;
}

form table, form td, form th {
	border:0;
	border-collapse:collapse;
	margin:auto;
	padding:5px;
	background: none;
}

input.date {
    width:40px;
}

form.lefttable {
	float:left;
}

form.lefttable table, form.lefttable td, form.lefttable th {
	border:1px solid #A8CCFF;
    background:#E5F0FF;
	border-collapse:collapse;
	margin:10px 0px 10px 0px;
}

form.righttable {
	float:left;
}

form.righttable table, form.righttable td, form.righttable th {
	border:1px solid #A8CCFF;
    background:#E5F0FF;
	border-collapse:collapse;
	margin:10px 0px 10px 0px;
}

.log_settings {
	float:right;
}

/* Playlist Filter Form Style */

.playlist_filterform table, .playlist_filterform  td, .playlist_filterform th {
	background: none;
	border-collapse:collapse;
	margin-left: 50px;
	margin-top: 30px;
}

form#playlist table, form#playlist td, form#playlist th{
	margin:0px;

}

/*Content add form*/

.tab_page{

}

/*Layout Style Div's*/

#current_table{
	float:left;
	width: 48%;
	margin-left: 0%;
}

#style_table{
	float:right;
	width: 48%;
	margin-right: 0%;
	
}

/*preview pane*/

#preview_pane{
	top: 10px;
	left:10px;
	background: white;
	border: 1px solid #DCE4F5;
}

form#selectors{
	background: #e5f0ff;
	padding: 5px;
	text-align: center;
}

/*whats playing */

#whatson_pane{
	top: 10px;
	left:10px;
	background: url(../../img/filterform/filterbackground.png) #E5F0FF;
	background-repeat: repeat-x;
	border: 2px solid #32659E;
	
}

#whatson_pane h1{
	color: #32659E;
}

#whatson_pane .info_table{
	width: 95%;
	margin:auto;
}

/*license form div's*/

.license {
	border: 1px solid #DCE4F5;
	background: url(../../img/filterform/filterbackground.png) #FFFFFF;
	background-repeat: repeat-x;
	padding: 10px;
	float:right;
	width: 40%;
	margin-right: 2%;
}

.license_info {
	border: 1px solid #DCE4F5;
	background: url(../../img/filterform/filterbackground.png) #FFFFFF;
	background-repeat: repeat-x;
	padding: 10px;
	float:left;
	width: 50%;
	margin-left: 2%;
}

.extralicenses{
	border: 1px solid #DCE4F5;
	background: url(../../img/filterform/filterbackground.png) #FFFFFF;
	background-repeat: repeat-x;
	padding: 10px;
	float:right;
	width: 40%;
	margin-right: 2%;
}

table.popup_table{
	border-collapse: collapse;
	margin: auto;
	table-layout: fixed;
	width: 465px;
}

#div_dialog, #div_dialog form {
	font-size: 10px;
	font-family: Verdana, Geneva, Arial, Helvetica, sans-serif;
}

label.error {
	color: #FF0000;
	padding-left: 25px;
	margin-top: 4px;
	display: block;
}

span.required {
	color: #FF0000;
}

input.required {
	color: #000000;
}

.connectedlist {
	float: left;
	width: 160px;
	margin: 5px;
}

.connectedlist h3 {
	padding: 5px;
}

.connectedlist .ui-sortable {
	width: 150px;
	background-color: #EEEEEE;
	padding: 5px;
}

.connectedlist .li-sortable {
	padding: 5px;
	margin: 5px;
	border: 1px solid #8080ff;
	background-color: #E5F0FF;
	width: 130px;
	cursor: pointer;
}

.listsubmit {
	clear:both;
}
