<?php
defined('VSIGN') or die("Sorry, you are not allowed to directly access this page.<br /> Please press the back button in your browser.");

/* Translations from the Database that need to be registered with Gettext */

echo __('Schedule');
echo __('Layout');
echo __('Library');
echo __('Administration');
echo __('Advanced');
echo __('Media');
echo __('Displays');
echo __('Groups');
echo __('Users');
echo __('Log');
echo __('License');
echo __('Sessions');
echo __('Settings');
echo __('Schedule');
echo __('Layouts');
echo __('Library');
echo __('Templates');
echo __('Settings');
echo __('Edit your Display');
echo __('Report Fault');
echo __('Statistics');
echo __('Display Groups');
echo __('Content');
echo __('Default');
echo __('Error');
echo __('General');
echo __('Path');
echo __('DataSets');
echo __('Modules');
echo __('Campaigns');

// Settings translations
echo __('jpg_length');
echo __('ppt_length');
echo __('swf_length');
echo __('defaultMedia');
echo __('defaultPlaylist');
echo __('defaultUsertype');
echo __('defaultTimezone');
echo __('debug');
echo __('audit');
echo __('SERVER_MODE');
echo __('SERVER_KEY');
echo __('PHONE_HOME');
echo __('LIBRARY_LOCATION');
echo __('MAINTENANCE_ENABLED');
echo __('MAINTENANCE_EMAIL_ALERTS');
echo __('MAINTENANCE_LOG_MAXAGE');
echo __('MAINTENANCE_STAT_MAXAGE');
echo __('MAINTENANCE_ALERT_TOUT');
echo __('MAINTENANCE_KEY');
echo __('MAINTENANCE_ALWAYS_ALERT');
echo __('mail_from');
echo __('mail_to');
echo __('SHOW_DISPLAY_AS_VNCLINK');
echo __('SHOW_DISPLAY_AS_VNC_TGT');
echo __('REGION_OPTIONS_COLOURING');
echo __('LAYOUT_COPY_MEDIA_CHECKB');
echo __('LIBRARY_MEDIA_UPDATEINALL_CHECKB');
echo __('USER_PASSWORD_POLICY');
echo __('USER_PASSWORD_ERROR');
echo __('MODULE_CONFIG_LOCKED_CHECKB');
echo __('LIBRARY_SIZE_LIMIT_KB');
echo __('MONTHLY_XMDS_TRANSFER_LIMIT_KB');
echo __('DEFAULT_LANGUAGE');
?>
