 $(document).ready(function(){
 	// Set up the Logout Timer
	setInterval("VsignPing('index.php?p=clock&q=GetClock')", 1000 * 60);
	
	setInterval("VsignPing('index.php?p=index&q=PingPong')", 1000 * 60 * 3); // Every 3 minutes	
 });