<div>
	<p style="text-align:center">VSign Digital Signage requires a valid user login to proceed.</p>
	<form id="VsignLoginForm" class="VsignForm" method="post" action="index.php?q=login">
		<div class="login_table">
			<table>
				<tr>
					<td><label for="username">User Name </label></td>
					<td><input class="username" type="text" id="username" name="username" tabindex="1" size="12" /></td>
				</tr>
				<tr>
					<td><label for="password">Password </label></td>
					<td><input class="password" id="password" type="password" name="password" tabindex="2" size="12" /></td>
				</tr>
			</table>
		</div>
	</form>
</div>