<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title>VSign Digital Signage Admin - Installation</title>
	<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
	<link rel="stylesheet" type="text/css" href="install/install.css" />
	
	<link rel="shortcut icon" href="img/favicon.ico" />
	
	<script type="text/javascript">
		$(document).ready(function(){
		
			document.getElementById('username').focus();
			
		});
	</script>

</head>

<body>

<div id="container">

	<div id="content">

		<div class="install_box">
			
			<div class="install_header">
				<div class="install_header_left">
				</div>

				<div class="install_header_right">
				</div>
			</div>
			<div class="install_body">
			<h1>VSign Digital Signage Installer</h1>			

