#CalendarTable {
	table-layout:fixed;
}

#Nav {
	width: 19em;
	vertical-align: top;
}

.gridContainer {
	overflow-y: visible;
	height: 483px;
}

.gridContainer6Weeks {
	overflow-y: visible;
	height: 640px;
}

.calendarContainer {
	height: 100%;
	position: relative;
	white-space: nowrap;
}

.eventsContainer {
	bottom: 0;
	left: 0;
	overflow: hidden;
	position: relative;
	top: 0;
	width: 100%;
	height: 100%;
}

.WeekDays {
	left: 0;
	top: 0;
	position: absolute;
	width: 100%;
	table-layout: fixed;
	padding: 5px;
	margin: 0;
}

.WeekDays td, .WeekDays th, .WeekDays tr {
	padding: 0;
	margin: 0;
}

.monthContainer {
	position: absolute;
	left: 0;
	top: 14px;
	overflow: hidden;
	width: 100%;
    height: 468px;
	border-top: 1px solid #000000;
}

.monthContainer6Weeks {
	position: absolute;
	left: 0;
	top: 14px;
	overflow: hidden;
	width: 100%;
    height: 600px;
	border-top: 1px solid #000000;
}

.MonthRow {
	left: 0;
	overflow: hidden;
	position: absolute;
	width: 100%;
}

.WeekRow {
	height: 100%;
	left: 0;
	position: absolute;
	table-layout: fixed;
	top: 0;
	width: 100%;
	padding: 0;
	margin: 0;
}

.WeekRow td, .WeekRow th, .WeekRow tr {
	padding: 0;
	margin: 0;
}

.EventsRow {
	position: relative;
	table-layout: fixed;
	width: 100%;
	padding: 0;
	margin: 0;
	border: 0;
}

.EventsRow td, .EventsRow th, .EventsRow tr {
	padding: 0;
	margin: 0;
	border: 0;
}

.EventsRow td {
	border-left: 1px solid #C3D9FF;
}

.DayGrid {
	border-left: 1px solid #C3D9FF;
	cursor: hand;
}

.nonmonthdays {
	background: grey;
}

.DayTitle {
	text-align: right;
	padding-right: 2px;
	background-color: #E0E9F6;
}

.CalEvent1 {
	background:#09A4F8;
}

.CalEvent2 {
	background:#8AB9BA;
}

.CalEvent3 {
	background:#86A2BA;
}

.Event {
	background: none !important;
}

.LongEvent, .Event {
	padding: 2px;
	margin-bottom: 1px;
        overflow-x: hidden;
}

#Displays {
	clear: both;
	padding-top: 25px;
}

.DisplayListForm {
	width: 210px;
}

/* Make sure each list appears on a new line */
ul.DisplayList li {
	clear:both;
}

/* Push the checkboxes out to the right */
ul.DisplayList li input {
	float:right;
}

/* Ensure the input for the display list box is as wide as the left hand pane */
input.DisplayListInput {
	width: 180px;
}

.DisplayList {
    width: 180px;
}

#Displays {
    height: 280px;
    overflow-y: scroll;
    overflow-x: hidden;
}

.FormDisplayList {
    height: 150px;
    overflow-y: scroll;
    overflow-x: hidden;
}
