<?php

defined('VSIGN') or die("Sorry, you are not allowed to directly access this page.<br /> Please press the back button in your browser.");

$msgAdd	= __('Add Help Link');

?>
<div id="form_container">
	<div id="form_header">
		<div id="form_header_left">
		</div>
		<div id="form_header_right">
		</div>
	</div>
	
	<div id="form_body">
		<div class="SecondNav">
			<!-- Maybe at a later date we could have these buttons generated from the DB - and therefore passed through the security system ? -->
			<ul>
				<li><a title="<?php echo $msgAdd; ?>" class="VsignFormButton" href="index.php?p=help&q=AddForm" ><span><?php echo $msgAdd; ?></span></a></li>
			</ul>
		</div>
		<?php $this->Filter(); ?>
	</div>
	<div id="form_footer">
		<div id="form_footer_left">
		</div>
		<div id="form_footer_right">
		</div>
	</div>
</div>	