/* This file contains the new styles for elements that I have added after Jim stopped doing the CSS */
.XiboGrid {
	clear: both;
	width: 100%;
}

.SecondNav, #headerback {
	text-align: center;
}

.SecondNav ul li, #headerback ul li {
	display: inline;
	padding-left: 15px;
	padding-right: 15px;
}

#headerback, #headerback a {
	color: #003399;
}

.FilterDiv {
	display: none;
}

.ReportFault ol li {
	display: list-item;
}


.HelpLink {
	float:right;
}

.moduleButtonImage {
	width: 55px;
}

.HelpLink a {
	padding-left: 10px;
	padding-right: 10px;
}

#embedHtml {
	width: 500px;
	height: 310px;
}

#embedScript {
	width: 500px;
	height: 140px;
}

.xiboformtextarea {
	width: 500px;
	height: 140px;
}

.regionTransparency {
	position: absolute;
	background-color: #FFF; 
	opacity: .80;
	filter: alpha(opacity=80);
}

.regionDisabled {
    opacity: .65;
    filter: alpha(opacity=65);
}

.footer {
	font-size:0.8em;
	text-align:right;
	padding-top: 15px;
	padding-right: 5px;
}

#system_working {
	position: absolute;
	left: 20px;
	top: 100px;
}

.nobr {
    white-space: nowrap;
}

.regionInfo {
    color:#FFF;
    background-color:#000;
    z-index:50;
    padding: 5px;
    position:absolute;
    right:15px;
    font-family: Verdana;
}

.seqInfo, .previewInfo {
    font-family: Verdana;
}

.seqInfo span, .previewInfo span {
    font-family: Verdana;
}

#aspectRatioOption {
    padding-bottom: 2px;
}


.preview {
    position:absolute;
    top:0px;
    left:0px;
    width: 100%;
    height: 100%;
}

.ui-dialog-buttonset .ui-button {
    float: right;
}

#secondaryMenu ul {
    padding: 0;
}

#secondaryMenu {
    float: left;
}

#secondaryMenu li {
    display: inline;
    padding-right: 55px;
}

#secondaryMenu .current {
    color: red;
}