<?php

?>
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title>VSign Message</title>
	<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
	<link rel="stylesheet" type="text/css" href="template/css/error.css" />
	
	<link rel="shortcut icon" href="img/favicon.ico" />
	
</head>

<body>

	<div class="message_box" style="padding:10px;">
			<div class="highlight"><?php echo $errorMessage; ?></div>
			<?php if($show_back) { echo "<a href=\"#\" onclick=\"history.go(-1);return false;\">Back</a>"; } ?>
	</div>
	
</body>

</html>