<?php
defined('VSIGN') or die("Sorry, you are not allowed to directly access this page.<br /> Please press the back button in your browser.");

if(Config::GetSetting($db, 'debug') == 'On')
    DEFINE('OAUTH_LOG_REQUEST', true);

// Output a discovery header
header('X-XRDS-Location:' . $serviceLocation . '/service.php?xrds');

require_once('3rdparty/oauth-php/library/OAuthServer.php');
require_once('3rdparty/oauth-php/library/OAuthStore.php');

OAuthStore::instance('MySQL', array('server' => $dbhost, 'username' => $dbuser, 'password' => $dbpass, 'database' => $dbname));

?>
