<?php
defined('VSIGN') or die("Sorry, you are not allowed to directly access this page.<br /> Please press the back button in your browser.");

class Template extends Data
{
    /**
     * Deletes a layout
     * @param <type> $layoutId
     * @return <type>
     */
    public function Delete($templateId)
    {
        $db =& $this->db;

        // Remove the Layout
        if (!$db->query(sprintf('DELETE FROM template WHERE TemplateId = %d', $templateId)))
            return $this->SetError(25105, __('Unable to delete template'));

        return true;
    }
}
?>