@import url(forms.css);
@import url(links.css);
@import url(vsign.css);
@import url(calendar.css);

body {
	background: url(../../img/headerback.png) repeat-x;
	font-size:76.1%;
	font-family:Verdana, Arial, Helvetica, sans-serif;
	margin:0;
	min-width:950px;
	width:expression(document.body.clientwidth <950? "950px": "auto");
}

div.dimmer 
{
    visibility: hidden;
    position:absolute;
    left:0px;
    top:0px;
    padding:40px;

    background-image:url(honey.png);
    /* ieWin only stuff */
        /* with this trick only IE 
           manage the following 2 attributes */   
    _background-image:none;
    _filter:progid:DXImageTransform.Microsoft.AlphaImageLoader(enabled=true, sizingMethod=scale src='honey.png');
}

/* Begin Customisation */

/* Standard Tags */
img {
	border:0px;
	
}

a {
	text-decoration:none;
}

a:link, a:visited {			/*text colour*/
	color:#003399;
	/*color:#FB000D;*/
}

p {
	margin-bottom: 1.2em;
	font-family:Arial;
	font-size:14px;
}

h4 {
	margin-top: 1.2em;
	font-family:Verdana, Arial, Helvetica, sans-serif;
	font-size:16px;
}

ul {
	/*list-style:disc outside;*/
	margin-left:1em;
	padding-left: 1em;
}

li {
	display:block;
}

h5 {
	margin-top: 1.2em;
}

.inside {
	padding:10px;
}

.highlight {
	clear:none;
	float:right;
	font-size:10px;
	border: 1px solid #003399;
	background: #E5F0FF;
	padding: 10px;
	text-align: center;
}

.button {
	border: 1px solid #003399;
	background: #E5F0FF;
	padding: 4px;
	text-align: center;
	line-height: 20px;
	width: 40px;
}

.cleared {
	clear:both;
}

.red {
	border: 1px solid #003399;
	background: url(../../img/filterform/filterbackground.png) #E5F0FF repeat-x;
	padding: 10px;
	text-align: center;
	color:red;
	width: 40%;
	margin:auto;
}

.orange {
	border: 1px solid #003399;
	background: #E5F0FF;
	padding: 10px;
	text-align: center;
	color:orange;
	width: 40%;
	margin:auto;
}

.green {
	border: 1px solid #003399;
	background: #E5F0FF;
	padding: 10px;
	text-align: center;
	color:green;
}


/* Default tables and forms */
table, td, th {
    background:#ffc;
    border:1px solid #DCE4F5; /*border table*/
	border-collapse:collapse;
	margin:10px 0px 10px 0px;
	padding:5px;
	font-size:1em;
}

tr.hover td {
	background:#e3ebf8;
}

th {
	background: #E0E9F6;
}

.centered {
	text-align:center;
}

.leftbuttons {
	float:right;
	
}

/*tabs*/
.tabs{
	display: block;
	text-align: center;
}

.tabs li {
	display: inline;
	position:relative;
	padding: 10px;
}

.active {
	color: red;

}
/* Help Div's */

#notes {
	position:absolute;
	top: 200px;
	right: 20px;
	float:right;
	width:400px;
	height: 400px;
	border: 1px solid #DCE4F5;
	margin-right: 20px;
	background: url(../../img/filterform/filterbackground.png) #E5F0FF;
	background-repeat: repeat-x;
	overflow-x: hidden; 
	overflow-y: scroll;
	z-index:1;
}

#notes h4 {
	background: url(../../img/forms/help.png);
	background-repeat: no-repeat;
	font-size: 1em;
	color: #1F6CC2;
	padding-left:50px;
	height: 40px;
	margin:0px;
	padding-top:15px;
}

#notes h5 {
	margin: 0px;
	padding-top: 2px;
	font-size:10px;
}

#notes p {
	font-size: 0.9em;
	
}

#helptabs ul{
	margin: 0px;
	padding-left: 5px;
	padding-right: 5px;
	padding-bottom: 0px;
	
}
#helptabs li{
	float:left;
	border-bottom: none;
	margin-right: 1px;
	background: #ffffff;
}

#helptabs a{

}

#helpbody{
	padding-top:0px;
	padding:5px;
	margin:5px;
	margin-top:0px;
	height: 95%;
	clear:both;
	background: #E5F0FF;
	background-repeat: repeat-x;
	
}

#tips_div{
	background: url(../../img/tabs/tabbackground.png) repeat-x #e5f0ff; 
	margin-top: 0px;
}

/*Main Divs*/
#container {
	width: 100%;
}

#headercontainer {
	/*border-bottom:1px solid #003399;*/
	width: 100%;
}

#header {
	text-align:center;
    background: url(../../img/header.png) no-repeat;
    color:#FFF;
    height: 55px;
    width: 500px;
    float: left;
	margin:0;
}

#header h4 {
	margin-top:0;
}

#headerback {
	float: right;
}

#contentwrap {
	border-top: 1px solid #003399;
	clear:both;
}	
	 	
#content {
    padding-top: 0px;
	padding-left: 10px;
	padding-right: 10px;
    clear:both;
}

#navigation {
	width:100%;
    /*background:#E5F0FF;*/
    /*border-top:1px solid #003399;
	border-bottom:1px solid #003399;*/
    clear: both;
  
}

#navigation, #nav ul {
	list-style:none;
	/*background:#E5F0FF;*/
	margin:0;
	padding:0;
	line-height:2em;
	
}

#navigation li {
	position: relative;
	margin:0;
	padding:0;
	/*background:#E5F0FF;*/
	border-bottom:1px solid #003399;
	float: left;
	width: 80px;
}


#navigation a:link, #navigation a:visited {
	margin:0;
	padding: 0px 20px;
    height:20px;
    line-height:20px;
    color:#003399;
}

#navigation a:hover {
    color: #000000;
	margin: 0;
}

#navigation li:hover ul, #navigation li.sfhover ul {
	
	margin-top: 5px;
	display: block;
 	background:#73A2D9;
 	border-bottom: 1px solid #003399;
 	list-style:none;
} 

#navigation ul li {
	margin: 0;
	position: relative;
	display: list-item;
	left: 0;
	border-bottom: 0px; 
	width: 150px;
	list-style:none;
	z-index:3;
}

 #navigation li ul {
 	margin: 0;
	position: absolute;
	padding: 0.25em;
	left: 0;
	top: 1.6em;
	display: none;
	width: 150px;
	border-left: 1px solid #003399;
    border-right: 1px solid #003399;
    border-bottom: 1px solid #003399;
}

#navigation a.current {
	color:red;
}

#check {
	color:red;
}

.leftfloated {
	float:left;
	margin-left:20px;
	margin-right:20px;
}

.rightfloated {
	float:right;
	margin-left:20px;
	margin-right:20px;
}

.defaulted_tab {
	
	
}

.display_info {
	float:right;
}

.display_boxes table {
 border: 1px solid #003399;
}

/* - DASHBOARD DIV's - */
#dashcontainer{
	background: url(../../img/fades/E5F0FFback.png);
}

dashschedule.strong{
	position: -25px;
}

#dashbuttons{	

	text-align: center;
}

.dashicons{
	height:125px;
	display: block;
	float: left;
	margin: 5px 5px;
	padding: 35px;
}

.dashiconsheaders{
	height:25px;
	display: block;
	float: right;
	margin: 3px 3px;
	padding: 15px;
}

.dashtextsheaders{
	display: block;
	float: right;
	margin: 3px;
}

.dash_button {
	display:block;
	text-align: center;
}

.dash_text {
	display:block;
}

.dashicons a:hover {
	color: #808080;
}

.dashboard_notes {
	clear:both;
	background:#E5F0FF;
	border:1px solid #A8CCFF;
	width: 100px;
	padding: 5px 5px 5px 5px;
	margin-top: 4px;	
}

.dashboard_notes p {
	padding: 5px 5px 5px 5px;
	font-size: 0.9em;
	margin: 0;	
}

.dashboard_notes h4 {
	margin: 0;
	background-image: url(../../img/info_icon.gif);
	background-repeat: no-repeat;
	background-position: top left;
	padding: 3px 0 3px 27px;
	border-bottom: 1px solid #000;
	font-size: 0.9em;
}

.color{
	color : navy;
}
/*Clear DIVS*/

/*form div's*/
#form_container{
	background: url(../../img/fades/E5F0FFback.png);
	background: url(../../img/fades/formbodymiddle.png) #FFFFFF repeat-x;
}

#form_header {
	background: url(../../img/fades/formheadmiddle.png);
	background-repeat: repeat-x;
	height: 35px;
	margin-top: 0px;
	margin-left: 0px;
	margin-right: 0px;
	

}
#form_header_left{
	background: url(../../img/fades/formheadleft.png);
	background-repeat: no-repeat;
	float:left;
	width:40px;
	height:35px;
	clear:both;
	margin-left: 0px;
	margin-right: 0px;
	
}

#form_header_right{
	background: url(../../img/fades/formheadright.png);
	background-repeat: no-repeat;
	float: right;
	width:20px;
	height:35px;
	margin-left: 0px;
	margin-right: 0px;
	
}

#form_body_left{
	background: url(../../img/fades/formbodyleft.png);
	background-repeat: repeat-y;
	width: 50px;
	right: 50px;
	margin-left: -100%;
	
	float:left;

}

#form_body{
	width:98%;
	margin: auto;
	margin-top: 0px;
}

#form_body_right{
	background: url(../../img/fades/formbodyright.png);
	background-repeat: repeat-y;
	width: 43px;
	float:right;


}

#form_footer {
	background: url(../../img/fades/formfootmiddle.png);
	height: 75px;
	margin-top: 0px;
	margin-left: 0px;
	margin-right: 0px;
	clear:both;
	

}
#form_footer_left{
	background: url(../../img/fades/formfootleft.png);
	background-repeat: no-repeat;
	float:left;
	width:40px;
	height:75px;
	clear:both;
	margin-left: 0px;
	margin-right: 0px;
}

#form_footer_right{
	background: url(../../img/fades/formfootright.png);
	background-repeat: no-repeat;
	float: right;
	width:40px;
	height:75px;
	margin-left: 0px;
	margin-right: 0px;
		
}

/*Filter form Div's works expect for IE 6, does not use the table layouts
#add_wrapper_div{
	position:absolute;
	top: 0pt;
	left: 0pt;	
	right:0pt;
	width:100%;
	height: 100%;
	min-height:1000px;
	min-width: 1000px;
	background:none;
	z-index:1;
}

#add_overlay_div{
	position:absolute;
	top: 0px;
	right: 0px;
	width:100%;
	height: 100%;
	min-height:100%;
	background: #1C2A56;
	background-repeat: repeat-x;
	z-index:1;
	height: auto; min-height: 100%;

}

#add_form_div {
	margin-top:15%;
	height: 40%;
	width: 100%;	
	position: absolute;
	text-align: center;
	z-index:10;

}
#add_form_center {
	position:relative;
	margin:auto;
	width:500px;
	height:300px;
	border: 1px solid #DCE4F5;
	background: url(../../img/filterform/filterbackground) #E5F0FF;
	background-repeat: repeat-x;

}
*/

#add_wrapper_div{
	height:100%;
	left:0px;
	overflow:visible;
	position:absolute;
	top:0px;
	right:0px;
	bottom:0px;
	width:100%;
	z-index:100;
}

#add_overlay_div{
	position:absolute;
	top: 0px;
	right: 0px;
	width:100%;
	height: 100%;
	min-height:100%;
	background: #1C2A56;
	background-repeat: repeat-x;
	z-index:1;
	height: auto; min-height: 100%;

}

#add_form_div {
	margin-top:15%;
	height: 40%;
	width: 100%;	
	position: absolute;
	text-align: center;
	z-index:10;

}
#add_form_center {
	position:relative;
	margin:auto;
	width:500px;
	height:300px;
	border: 1px solid #DCE4F5;
	background: url(../../img/filterform/filterbackground) #E5F0FF;
	background-repeat: repeat-x;

}

#playlist_filterform_div {
	
	margin-left:25%;
	background: url(../../img/filterform/filterbackground.png) #E5F0FF;
	background-repeat: repeat-x;
	width: 45%;
	padding-bottom: 20px;
	padding-top:10px;
	border: 1px solid #DCE4F5;
	display:hidden;
	z-index: 0;
}

#filter_form {
	margin: auto;
	background: none;
	
}

#content_filterform_div {
	margin-left:25%;
	background: url(../../img/filterform/filterbackground.png) #E5F0FF;
	background-repeat: repeat-x;
	width: 45%;
	padding-left: 10px;
	padding-top:10px;
	border: 1px solid #DCE4F5;
	display:hidden;
}

/*presentation add forms*/
.pres_add{
	clear:both;
	width: 80%;
	margin: auto;
}

/*presentation edit forms*/

.page_intro{
	float:left;
}

.pres_edit {
	border: 1px solid #DCE4F5;
	background: url(../../img/filterform/filterbackground.png) #E5F0FF;
	background-repeat: repeat-x;
	margin-left: 25%;
	display:block;
	width: 40%;
	clear:both;
}

.slidetable{
	width:98%;
	clear:both;
}

/*Chart forms */

.edit_chart_dataset{
	float: left;
	width: 50%;
	margin-left: 10px;
}

.chart_fields{
	float: right;
	width: 45%;
	margin-left: 10px;
}

.chart_preview{
	width: 800px;
	clear:both;
	margin: auto;
}

/*data table items */

#data_table {
	clear:both;
	width: 100%;
}

.pages {
	float:right;
	display:inline;
	width: 115px;
	clear:both;
}

.info_table{
	clear:both;
	width: 100%;
	
}

#log_table {
	clear:both;
}

#preview {
	clear:both;
	background: #ffffff;
	margin:auto;
	margin-left:10%;
	margin-top: 5%;
	text-align:center;
	height:600px;
	width:800px;
}

 .title {
	margin:0px;
	padding-top:0.5px;
	text-align:center;
}

.title h4{
	margin-bottom:0.4em;
	margin-top:0.4em;
	color:#25457A;
	
}	

.formbody{
	padding: 15px;
}

.formbody p{
	color:#FFE08B;
}
/*
.title {
	background: url(../../img/titles/header.png) no-repeat;
	padding-left: 5px;
	margin-bottom: 0px;
}

.title h4{
	color:#fff;
	font-size: 20px;
	padding-top:15px;
	padding-bottom:10px;
	margin-bottom:0px;
}	

.formbody{
	background: url(../../img/bodys/bodyback.png) repeat-x;
	padding: 5px;
}

td.error {
	color:red;
}

/*Data table*/
.dataset_table {
	clear:both;
}

.dataset_table table, .dataset_table tr, .dataset_table td {
	padding:0px;
}

.dataset_table form {
	display:inline;
	padding: 0;
	margin: 0;
}

.dataset_table tr{
	height: 20px;
}


#mediaformwrap{
	width: 90%;
	margin: auto;
	clear:both;
}

#csv_import{
	width: 98%;
	margin:auto;
	
	}

/*settings tabs*/

#settings {
	width: 90%;
	margin:auto;
	clear:both;
}

#csv_import table, #csv_import td, #csv_import th {

    background:#fff;
    border:1px solid #DCE4F5;
	
	border-collapse:collapse;
	margin:10px 0px 10px 0px;
	padding:5px;
	font-size:1em;
}

.region
{
	cursor:pointer;
}

.regionicons{
	display: block;
	float: left;
	margin: 5px 5px;
	padding: 5px;
}

.region_button {
	display:block;
	text-align: center;
}

.region_text {
	display:block;
}

.regionicons a:hover {
	color: #808080;
}

.timebar
{
	color:#A5C4E7;
	height:62px;
}

.timebar_powerpoint_left{
	background:url(../../img/forms/blue_bar.gif) no-repeat;
	background-position:top left;
	height:59px;
	width:9px;
	float:left;
}

.timebar_powerpoint_right{
	background:url(../../img/forms/blue_bar.gif) no-repeat;
	background-position:top right;
	height:59px;
	margin-left:9px;
}

.timebar_image_left{
	background:url(../../img/forms/red_bar.gif) no-repeat;
	background-position:top left;
	height:59px;
	width:9px;
	float:left;
}

.timebar_image_right{
	background:url(../../img/forms/red_bar.gif) no-repeat;
	background-position:top right;
	height:59px;
	margin-left:9px;
}

.timebar_webpage_left{
	background:url(../../img/forms/green_bar.gif) no-repeat;
	background-position:top left;
	height:59px;
	width:9px;
	float:left;
}

.timebar_webpage_right{
	background:url(../../img/forms/green_bar.gif) no-repeat;
	background-position:top right;
	height:59px;
	margin-left:9px;
}

.timebar_shellcommand_left{
	background:url(../../img/forms/green_bar.gif) no-repeat;
	background-position:top left;
	height:59px;
	width:9px;
	float:left;
}

.timebar_shellcommand_right{
	background:url(../../img/forms/green_bar.gif) no-repeat;
	background-position:top right;
	height:59px;
	margin-left:9px;
}

.timebar_microblog_left{
    background:url(../../img/forms/orange_bar.gif) no-repeat;
    background-position:top left;
    height:59px;
    width:9px;
    float:left;
}

.timebar_microblog_right{
    background:url(../../img/forms/orange_bar.gif) no-repeat;
    background-position:top right;
    height:59px;
    margin-left:9px;
}

.timebar_embedded_left{
	background:url(../../img/forms/green_bar.gif) no-repeat;
	background-position:top left;
	height:59px;
	width:9px;
	float:left;
}

.timebar_embedded_right{
	background:url(../../img/forms/green_bar.gif) no-repeat;
	background-position:top right;
	height:59px;
	margin-left:9px;
}

.timebar_text_left{
	background:url(../../img/forms/yellow_bar.gif) no-repeat;
	background-position:top left;
	height:59px;
	width:9px;
	float:left;
}

.timebar_text_right{
	background:url(../../img/forms/yellow_bar.gif) no-repeat;
	background-position:top right;
	height:59px;
	margin-left:9px;
}
.timebar_ticker_left{
	background:url(../../img/forms/orange_bar.gif) no-repeat;
	background-position:top left;
	height:59px;
	width:9px;
	float:left;
}

.timebar_ticker_right{
	background:url(../../img/forms/orange_bar.gif) no-repeat;
	background-position:top right;
	height:59px;
	margin-left:9px;
}
.timebar_video_left{
	background:url(../../img/forms/purple_bar.gif) no-repeat;
	background-position:top left;
	height:59px;
	width:9px;
	float:left;
}

.timebar_video_right{
	background:url(../../img/forms/purple_bar.gif) no-repeat;
	background-position:top right;
	height:59px;
	margin-left:9px;
}
.timebar_flash_left{
	background:url(../../img/forms/grey_bar.gif) no-repeat;
	background-position:top left;
	height:59px;
	width:9px;
	float:left;
}

.timebar_flash_right{
	background:url(../../img/forms/grey_bar.gif) no-repeat;
	background-position:top right;
	height:59px;
	margin-left:9px;
}

.timebar_enabled_left{
	background:url(../../img/forms/green_bar.gif) no-repeat;
	background-position:top left;
	height:59px;
	width:9px;
	float:left;
}

.timebar_enabled_right{
	background:url(../../img/forms/green_bar.gif) no-repeat;
	background-position:top right;
	height:59px;
	margin-left:9px;
}

.timebar_disabled_left{
	background:url(../../img/forms/grey_bar.gif) no-repeat;
	background-position:top left;
	height:59px;
	width:9px;
	float:left;
}

.timebar_disabled_right{
	background:url(../../img/forms/grey_bar.gif) no-repeat;
	background-position:top right;
	height:59px;
	margin-left:9px;
}

#timeline table
{
	width:100%;
}

#timeline{
	height:164px;
	width: 980px;
	background:url(../../img/forms/background_timeline.png) no-repeat;
	float:left;
}

#timeline_body{
	height:164px;
	background: url(../../img/forms/main_right_timeline.png);
	position: top right;
	margin-left:20px;
}

#timeline_right{
	height:164px;
}

.mediabreak{
	background:url(../../img/forms/line_break.png) no-repeat;
	width:9px;
	height:164px;
	z-index:2;
	float:left;
}

.tooltip_hidden
{
	display:none;
}

#tooltip_hover
{
	display:block;
	background: url(../../img/forms/previewback.png) repeat-x #fff;
	border: 2px solid #DCE4F5;
	padding: 10px;
	z-index:15;
        overflow-x: hidden;
        overflow-y: scroll;
}

#tooltip_hover li {
    list-style-type: disc;
}

.scrollingWindow 
{
	overflow-y: scroll;
}
