				<br />
				<p><a href="http://lokon.vs.co.id"><img src='img/login/complogo.png'></a></p>	
			</div>

			
			<div class="install_foot">
				<div class="install_foot_left">
				</div>
				<div class="install_foot_right">
				</div>
			</div>
		</div>
		
</div>

</body>
</html>
