<?php

defined('VSIGN') or die("Sorry, you are not allowed to directly access this page.<br /> Please press the back button in your browser.");

?>
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title>VSign Digital Signage - Please Login</title>
	<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
	<link rel="stylesheet" type="text/css" href="template/css/login_box.css" />
	<link rel="stylesheet" type="text/css" href="3rdparty/jQuery/ui-elements.css" />
	
	<link rel="shortcut icon" href="img/favicon.ico" />
	
        <!-- Javascript Libraries -->
        <script type="text/javascript" src="3rdparty/jQuery/jquery.min.js"></script>
        <script type="text/javascript" src="3rdparty/jQuery/jquery-ui.min.js"></script>
        <link rel="stylesheet" type="text/css" href="3rdparty/jQuery/css/jquery-ui.css" />

        <script type="text/javascript" src="3rdparty/jQuery/jquery.form.js"></script>
        <script type="text/javascript" src="3rdparty/jQuery/jquery.validate.min.js"></script>
        <script type="text/javascript" src="3rdparty/jQuery/jquery.tablesorter.pack.js"></script>
        <script type="text/javascript" src="3rdparty/jQuery/jquery.tablesorter.pager.js"></script>
        <script type="text/javascript" src="3rdparty/jQuery/jquery.ifixpng.js"></script>
        <script type="text/javascript" src="3rdparty/jQuery/jquery.contextmenu.r2.packed.js"></script>
        <script type="text/javascript" src="3rdparty/jQuery/jquery.corner.js"></script>
        <script type="text/javascript" src="lib/js/functions.js"></script>
	<script type="text/javascript" src="lib/js/core.js"></script>
	
	<script type="text/javascript">
		$(document).ready(function(){
		
			$('input[type=text]').eq(0).focus();
			
			$('#forgotten').click(function() {
				$('#forgotten_details').toggle();
			});
		
		});
	</script>
</head>

<body>

<div id="container">

	<div id="head_wrapper">
	<div id="login_headtop"><br/>VSIGN DIGITAL SIGNAGE</div>
	</div>

	<div id="content">
		<table border="0" width="100%">
		
		<tr><td width="70%" align="center"><br/><br/><div><img src="img/login/vsign5.png"></div>
			<br/>
			<br/>
			<div style="font-family:verdana;font-size:14pt"><b>Solusi media komunikasi masa depan</b></div>
			<br/>
			<div style="font-family:verdana;font-size:12pt;width:400px;text-align:justify">Kemajuan teknologi menuntut distribusi informasi secara cepat, real time, dan terpercaya, VSign Digital Signage hadir menjadi solusi bagi kebutuhan media informasi dan komunikasi anda.</div>
			<br/>
			<br/>

		</td><td>

		<div class="lgbx">
		<div class="login_box">
			
			<div id="fslogin">
				<h1>Login</h1>
				<form method="post" action="index.php?q=login&referingPage=<?php echo $referingPage; ?>">
					<input type="hidden" name="token" value="<?php echo CreateFormToken() ?>" />
					<div class="login_table">
						<p1><input class="username" type="text" id="username" name="username" tabindex="1" size="12" placeholder="User Name"/></p1>
						<br />
						<br />
						<p1><input class="password" id="password" type="password" name="password" tabindex="2" size="12" placeholder="Password"/></p1>
						<br />
						<br />
						<br />
						<br />
						<!--<a href="#" id="forgotten">Forgotten Password?</a>-->
					</div>
					<div class="loginbuton"><button class="logbutton" type="submit" tabindex="3">Log in</button></div>
				</form>
				
				<br />
				<br />
				<?php displayMessage(); ?>
				<br />
			</div>
			

		</div>
		</div>
	</td></tr>
</table>
		
	</div>
	<div id="footer_wrapper"><div id="login_footer" ><div style="width:98%;"><br/>Copyright &copy; 2013</div></div></div>
</div>
	<div id="system_working" style="display:none;"><img src="img/loading.gif"></div>
	
	<div id="system_message" style="text-align: center;">
		<span>Message</span>
	</div>
	
	<div id="div_dialog"></div>
	</body>
</html>
